@@ -7,7 +7,7 @@ use UNIVERSAL;
 #			C Language Mapping Specification, New Edition June 1999
 #
 
-package CliteralVisitor;
+package CORBA::C::literalVisitor;
 
 # needs $node->{c_name} (CnameVisitor) for Enum
 # builds $node->{c_literal}
@@ -17,20 +17,20 @@ sub new {
 	my $class = ref($proto) || $proto;
 	my $self = {};
 	bless($self, $class);
-	my($parser) = @_;
+	my ($parser) = @_;
 	$self->{key} = 'c_literal';
 	$self->{symbtab} = $parser->YYData->{symbtab};
 	return $self;
 }
 
-sub visitNameType {
+sub visitType {
 	my $self = shift;
 	my ($type) = @_;
 
 	if (ref $type) {
-		$type->visitName($self);
+		$type->visit($self);
 	} else {
-		$self->{symbtab}->Lookup($type)->visitName($self);
+		$self->{symbtab}->Lookup($type)->visit($self);
 	}
 }
 
@@ -38,11 +38,11 @@ sub visitNameType {
 #	3.5		OMG IDL Specification
 #
 
-sub visitNameSpecification {
+sub visitSpecification {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_export}}) {
-		$self->{symbtab}->Lookup($_)->visitName($self);
+		$self->{symbtab}->Lookup($_)->visit($self);
 	}
 }
 
@@ -50,11 +50,11 @@ sub visitNameSpecification {
 #	3.7		Module Declaration
 #
 
-sub visitNameModules {
+sub visitModules {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_export}}) {
-		$self->{symbtab}->Lookup($_)->visitName($self);
+		$self->{symbtab}->Lookup($_)->visit($self);
 	}
 }
 
@@ -62,38 +62,42 @@ sub visitNameModules {
 #	3.8		Interface Declaration
 #
 
-sub visitNameBaseInterface {
+sub visitBaseInterface {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	return if (exists $node->{$self->{key}});
 	$node->{$self->{key}} = 1;
 	foreach (@{$node->{list_export}}) {
-		$self->{symbtab}->Lookup($_)->visitName($self);
+		$self->{symbtab}->Lookup($_)->visit($self);
 	}
 }
 
+sub visitForwardBaseInterface {
+	# empty
+}
+
 #
 #	3.9		Value Declaration
 #
 
-sub visitNameStateMember {
+sub visitStateMember {
 	# C mapping is aligned with CORBA 2.1
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});	# type_spec
+	my ($node) = @_;
+	$self->visitType($node->{type});	# type_spec
 	if (exists $node->{array_size}) {
 		foreach (@{$node->{array_size}}) {
-			$_->visitName($self);			# expression
+			$_->visit($self);			# expression
 		}
 	}
 }
 
-sub visitNameInitializer {
+sub visitInitializer {
 	# C mapping is aligned with CORBA 2.1
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_param}}) {
-		$_->visitName($self);				# parameter
+		$_->visit($self);				# parameter
 	}
 }
 
@@ -101,15 +105,15 @@ sub visitNameInitializer {
 #	3.10	Constant Declaration
 #
 
-sub visitNameConstant {
+sub visitConstant {
 	my $self = shift;
-	my($node) = @_;
-	$node->{value}->visitName($self);		# expression
+	my ($node) = @_;
+	$node->{value}->visit($self);		# expression
 }
 
 sub _Eval {
 	my $self = shift;
-	my($list_expr, $type) = @_;
+	my ($list_expr, $type) = @_;
 	my $elt = pop @{$list_expr};
 	unless (ref $elt) {
 		$elt = $self->{symbtab}->Lookup($elt);
@@ -130,7 +134,7 @@ sub _Eval {
 	} elsif ( $elt->isa('Enum') ) {
 		return $elt->{c_name};
 	} elsif ( $elt->isa('Literal') ) {
-		$elt->visitName($self, $type);
+		$elt->visit($self, $type);
 		return $elt->{$self->{key}};
 	} else {
 		warn __PACKAGE__,"::_Eval: INTERNAL ERROR ",ref $elt,".\n";
@@ -138,42 +142,44 @@ sub _Eval {
 	}
 }
 
-sub visitNameExpression {
+sub visitExpression {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	my @list_expr = @{$node->{list_expr}};		# create a copy
 	$node->{$self->{key}} = $self->_Eval(\@list_expr, $node->{type});
 }
 
-sub visitNameIntegerLiteral {
+sub visitIntegerLiteral {
 	my $self = shift;
-	my($node,$type) = @_;
+	my ($node, $type) = @_;
 	my $str = $node->{value};
 	$str =~ s/^\+//;
 	unless (exists $type->{auto}) {
-		if (	  $type->{value} eq 'unsigned short' ) {
-			$str .= 'U';
+		if (	  $type->{value} eq 'short' ) {
+			$str = "(short)" . $str;
+		} elsif ( $type->{value} eq 'unsigned short' ) {
+			$str = "(unsigned short)" . $str;
 		} elsif ( $type->{value} eq 'long' ) {
-			$str .= 'L';
-		} elsif ( $type->{value} eq 'long long' ) {
-			$str .= 'LL';
+			$str .= "L";
 		} elsif ( $type->{value} eq 'unsigned long' ) {
-			$str .= 'UL';
+			$str .= "UL";
+		} elsif ( $type->{value} eq 'long long' ) {
+			$str .= "LL";
 		} elsif ( $type->{value} eq 'unsigned long long' ) {
-			$str .= 'ULL';
+			$str .= "ULL";
 		}
 	}
 	$node->{$self->{key}} = $str;
 }
 
-sub visitNameStringLiteral {
+sub visitStringLiteral {
 	my $self = shift;
-	my($node) = @_;
-	my @list = unpack "C*",$node->{value};
+	my ($node) = @_;
+	my @list = unpack "C*", $node->{value};
 	my $str = "\"";
 	foreach (@list) {
 		if ($_ < 32 or $_ >= 128) {
-			$str .= sprintf "\\x%02x",$_;
+			$str .= sprintf "\\x%02x", $_;
 		} else {
 			$str .= chr $_;
 		}
@@ -182,16 +188,16 @@ sub visitNameStringLiteral {
 	$node->{$self->{key}} = $str;
 }
 
-sub visitNameWideStringLiteral {
+sub visitWideStringLiteral {
 	my $self = shift;
-	my($node) = @_;
-	my @list = unpack "C*",$node->{value};
+	my ($node) = @_;
+	my @list = unpack "C*", $node->{value};
 	my $str = "L\"";
 	foreach (@list) {
 		if ($_ < 32 or ($_ >= 128 and $_ < 256)) {
-			$str .= sprintf "\\x%02x",$_;
+			$str .= sprintf "\\x%02x", $_;
 		} elsif ($_ >= 256) {
-			$str .= sprintf "\\u%04x",$_;
+			$str .= sprintf "\\u%04x", $_;
 		} else {
 			$str .= chr $_;
 		}
@@ -200,14 +206,14 @@ sub visitNameWideStringLiteral {
 	$node->{$self->{key}} = $str;
 }
 
-sub visitNameCharacterLiteral {
+sub visitCharacterLiteral {
 	my $self = shift;
-	my($node) = @_;
-	my @list = unpack "C",$node->{value};
+	my ($node) = @_;
+	my @list = unpack "C", $node->{value};
 	my $c = $list[0];
 	my $str = "'";
 	if ($c < 32 or $c >= 128) {
-		$str .= sprintf "\\x%02x",$c;
+		$str .= sprintf "\\x%02x", $c;
 	} else {
 		$str .= chr $c;
 	}
@@ -215,16 +221,16 @@ sub visitNameCharacterLiteral {
 	$node->{$self->{key}} = $str;
 }
 
-sub visitNameWideCharacterLiteral {
+sub visitWideCharacterLiteral {
 	my $self = shift;
-	my($node) = @_;
-	my @list = unpack "C",$node->{value};
+	my ($node) = @_;
+	my @list = unpack "C", $node->{value};
 	my $c = $list[0];
 	my $str = "L'";
 	if ($c < 32 or ($c >= 128 and $c < 256)) {
-		$str .= sprintf "\\x%02x",$c;
+		$str .= sprintf "\\x%02x", $c;
 	} elsif ($c >= 256) {
-		$str .= sprintf "\\u%04x",$c;
+		$str .= sprintf "\\u%04x", $c;
 	} else {
 		$str .= chr $c;
 	}
@@ -232,24 +238,24 @@ sub visitNameWideCharacterLiteral {
 	$node->{$self->{key}} = $str;
 }
 
-sub visitNameFixedPtLiteral {
+sub visitFixedPtLiteral {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	my $str = "\"";
 	$str .= $node->{value};
 	$str .= "\"";
 	$node->{$self->{key}} = $str;
 }
 
-sub visitNameFloatingPtLiteral {
+sub visitFloatingPtLiteral {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	$node->{$self->{key}} = $node->{value};
 }
 
-sub visitNameBooleanLiteral {
+sub visitBooleanLiteral {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	if ($node->{value} eq 'TRUE') {
 		$node->{$self->{key}} = '1';
 	} else {
@@ -261,14 +267,14 @@ sub visitNameBooleanLiteral {
 #	3.11	Type Declaration
 #
 
-sub visitNameTypeDeclarator {
+sub visitTypeDeclarator {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	return if (exists $node->{modifier});	# native IDL2.2
-	$self->visitNameType($node->{type});
+	$self->visitType($node->{type});
 	if (exists $node->{array_size}) {
 		foreach (@{$node->{array_size}}) {
-			$_->visitName($self);			# expression
+			$_->visit($self);			# expression
 		}
 	}
 }
@@ -277,11 +283,11 @@ sub visitNameTypeDeclarator {
 #	3.11.1	Basic Types
 #
 
-sub visitNameBasicType {
+sub visitBasicType {
 	# empty
 }
 
-sub visitNameAnyType {
+sub visitAnyType {
 	# empty
 }
 
@@ -291,78 +297,74 @@ sub visitNameAnyType {
 #	3.11.2.1	Structures
 #
 
-sub visitNameStructType {
+sub visitStructType {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	return if (exists $node->{$self->{key}});
 	$node->{$self->{key}} = 1;
-	foreach (@{$node->{list_value}}) {
-		$self->visitNameType($_);			# single or array
+	foreach (@{$node->{list_member}}) {
+		$self->visitType($_);			# member
 	}
 }
 
-sub visitNameArray {
+sub visitMember {
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});
-	foreach (@{$node->{array_size}}) {
-		$_->visitName($self);				# expression
+	my ($node) = @_;
+	$self->visitType($node->{type});
+	if (exists $node->{array_size}) {
+		foreach (@{$node->{array_size}}) {
+			$_->visit($self);				# expression
+		}
 	}
 }
 
-sub visitNameSingle {
-	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});
-}
-
 #	3.11.2.2	Discriminated Unions
 #
 
-sub visitNameUnionType {
+sub visitUnionType {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	return if (exists $node->{$self->{key}});
 	$node->{$self->{key}} = 1;
-	$self->visitNameType($node->{type});
+	$self->visitType($node->{type});
 	foreach (@{$node->{list_expr}}) {
-		$_->visitName($self);				# case
+		$_->visit($self);				# case
 	}
 }
 
-sub visitNameCase {
+sub visitCase {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_label}}) {
-		$_->visitName($self);				# default or expression
+		$_->visit($self);				# default or expression
 	}
-	$node->{element}->visitName($self);		# array or single
+	$node->{element}->visit($self);
 }
 
-sub visitNameDefault {
+sub visitDefault {
 	# empty
 }
 
-sub visitNameElement {
+sub visitElement {
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{value});	# single or array
+	my ($node) = @_;
+	$self->visitType($node->{value});	# member
 }
 
 #	3.11.2.4	Enumerations
 #
 
-sub visitNameEnumType {
+sub visitEnumType {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_expr}}) {
-		$_->visitName($self);				# enum
+		$_->visit($self);				# enum
 	}
 }
 
-sub visitNameEnum {
+sub visitEnum {
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	$node->{$self->{key}} = $node->{value};
 }
 
@@ -370,33 +372,33 @@ sub visitNameEnum {
 #	3.11.3	Template Types
 #
 
-sub visitNameSequenceType {
+sub visitSequenceType {
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});
-	$node->{max}->visitName($self) if (exists $node->{max});
+	my ($node) = @_;
+	$self->visitType($node->{type});
+	$node->{max}->visit($self) if (exists $node->{max});
 }
 
-sub visitNameStringType {
+sub visitStringType {
 	my $self = shift;
-	my($node) = @_;
-	$node->{max}->visitName($self) if (exists $node->{max});
+	my ($node) = @_;
+	$node->{max}->visit($self) if (exists $node->{max});
 }
 
-sub visitNameWideStringType {
+sub visitWideStringType {
 	my $self = shift;
-	my($node) = @_;
-	$node->{max}->visitName($self) if (exists $node->{max});
+	my ($node) = @_;
+	$node->{max}->visit($self) if (exists $node->{max});
 }
 
-sub visitNameFixedPtType {
+sub visitFixedPtType {
 	my $self = shift;
-	my($node) = @_;
-	$node->{d}->visitName($self);
-	$node->{s}->visitName($self);
+	my ($node) = @_;
+	$node->{d}->visit($self);
+	$node->{s}->visit($self);
 }
 
-sub visitNameFixedPtConstType {
+sub visitFixedPtConstType {
 	# empty
 }
 
@@ -404,11 +406,11 @@ sub visitNameFixedPtConstType {
 #	3.12	Exception Declaration
 #
 
-sub visitNameException {
+sub visitException {
 	my $self = shift;
-	my($node) = @_;
-	foreach (@{$node->{list_value}}) {
-		$self->visitNameType($_);			# single or array
+	my ($node) = @_;
+	foreach (@{$node->{list_member}}) {
+		$self->visitType($_);			# member
 	}
 }
 
@@ -416,22 +418,22 @@ sub visitNameException {
 #	3.13	Operation Declaration
 #
 
-sub visitNameOperation {
+sub visitOperation {
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});	# param_type_spec or void
+	my ($node) = @_;
+	$self->visitType($node->{type});	# param_type_spec or void
 	foreach (@{$node->{list_param}}) {
-		$_->visitName($self);				# parameter
+		$_->visit($self);				# parameter
 	}
 }
 
-sub visitNameParameter {
+sub visitParameter {
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});	# param_type_spec
+	my ($node) = @_;
+	$self->visitType($node->{type});	# param_type_spec
 }
 
-sub visitNameVoidType {
+sub visitVoidType {
 	# empty
 }
 
@@ -439,21 +441,21 @@ sub visitNameVoidType {
 #	3.14	Attribute Declaration
 #
 
-sub visitNameAttribute {
+sub visitAttribute {
 	my $self = shift;
-	my($node) = @_;
-	$self->visitNameType($node->{type});	# param_type_spec
+	my ($node) = @_;
+	$self->visitType($node->{type});	# param_type_spec
 }
 
 #
 #	3.15	Repository Identity Related Declarations
 #
 
-sub visitNameTypeId {
+sub visitTypeId {
 	# empty
 }
 
-sub visitNameTypePrefix {
+sub visitTypePrefix {
 	# empty
 }
 
@@ -465,23 +467,23 @@ sub visitNameTypePrefix {
 #	3.17	Component Declaration
 #
 
-sub visitNameProvides {
+sub visitProvides {
 	# empty
 }
 
-sub visitNameUses {
+sub visitUses {
 	# empty
 }
 
-sub visitNamePublishes {
+sub visitPublishes {
 	# empty
 }
 
-sub visitNameEmits {
+sub visitEmits {
 	# empty
 }
 
-sub visitNameConsumes {
+sub visitConsumes {
 	# empty
 }
 
@@ -489,21 +491,21 @@ sub visitNameConsumes {
 #	3.18	Home Declaration
 #
 
-sub visitNameFactory {
+sub visitFactory {
 	# C mapping is aligned with CORBA 2.1
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_param}}) {
-		$_->visitName($self);				# parameter
+		$_->visit($self);				# parameter
 	}
 }
 
-sub visitNameFinder {
+sub visitFinder {
 	# C mapping is aligned with CORBA 2.1
 	my $self = shift;
-	my($node) = @_;
+	my ($node) = @_;
 	foreach (@{$node->{list_param}}) {
-		$_->visitName($self);				# parameter
+		$_->visit($self);				# parameter
 	}
 }
 
